==> zio-aws-inspector2_3-5.17.190.2-sources.jar: zio/aws/inspector2/model/CoverageResourceType.scala <==
package zio.aws.inspector2.model
import scala.jdk.CollectionConverters.*
sealed trait CoverageResourceType {
  def unwrap
      : software.amazon.awssdk.services.inspector2.model.CoverageResourceType
}
object CoverageResourceType {
  def wrap(
      value: software.amazon.awssdk.services.inspector2.model.CoverageResourceType
  ): zio.aws.inspector2.model.CoverageResourceType = value match {
    case software.amazon.awssdk.services.inspector2.model.CoverageResourceType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_EC2_INSTANCE =>
      val r = AWS_EC2_INSTANCE
      r
    case software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_ECR_CONTAINER_IMAGE =>
      val r = AWS_ECR_CONTAINER_IMAGE
      r
    case software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_ECR_REPOSITORY =>
      val r = AWS_ECR_REPOSITORY
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.inspector2.model.CoverageResourceType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.CoverageResourceType =
      software.amazon.awssdk.services.inspector2.model.CoverageResourceType.UNKNOWN_TO_SDK_VERSION
  }
  case object AWS_EC2_INSTANCE
      extends zio.aws.inspector2.model.CoverageResourceType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.CoverageResourceType =
      software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_EC2_INSTANCE
  }
  case object AWS_ECR_CONTAINER_IMAGE
      extends zio.aws.inspector2.model.CoverageResourceType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.CoverageResourceType =
      software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_ECR_CONTAINER_IMAGE
  }
  case object AWS_ECR_REPOSITORY
      extends zio.aws.inspector2.model.CoverageResourceType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.CoverageResourceType =
      software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_ECR_REPOSITORY
  }
}

==> zio-aws-inspector2_3-7.28.29.8-sources.jar: zio/aws/inspector2/model/CoverageResourceType.scala <==
package zio.aws.inspector2.model
import scala.jdk.CollectionConverters.*
sealed trait CoverageResourceType {
  def unwrap
      : software.amazon.awssdk.services.inspector2.model.CoverageResourceType
}
object CoverageResourceType {
  def wrap(
      value: software.amazon.awssdk.services.inspector2.model.CoverageResourceType
  ): zio.aws.inspector2.model.CoverageResourceType = value match {
    case software.amazon.awssdk.services.inspector2.model.CoverageResourceType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_EC2_INSTANCE =>
      val r = AWS_EC2_INSTANCE
      r
    case software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_ECR_CONTAINER_IMAGE =>
      val r = AWS_ECR_CONTAINER_IMAGE
      r
    case software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_ECR_REPOSITORY =>
      val r = AWS_ECR_REPOSITORY
      r
    case software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_LAMBDA_FUNCTION =>
      val r = AWS_LAMBDA_FUNCTION
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.inspector2.model.CoverageResourceType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.CoverageResourceType =
      software.amazon.awssdk.services.inspector2.model.CoverageResourceType.UNKNOWN_TO_SDK_VERSION
  }
  case object AWS_EC2_INSTANCE
      extends zio.aws.inspector2.model.CoverageResourceType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.CoverageResourceType =
      software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_EC2_INSTANCE
  }
  case object AWS_ECR_CONTAINER_IMAGE
      extends zio.aws.inspector2.model.CoverageResourceType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.CoverageResourceType =
      software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_ECR_CONTAINER_IMAGE
  }
  case object AWS_ECR_REPOSITORY
      extends zio.aws.inspector2.model.CoverageResourceType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.CoverageResourceType =
      software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_ECR_REPOSITORY
  }
  case object AWS_LAMBDA_FUNCTION
      extends zio.aws.inspector2.model.CoverageResourceType {
    override def unwrap
        : software.amazon.awssdk.services.inspector2.model.CoverageResourceType =
      software.amazon.awssdk.services.inspector2.model.CoverageResourceType.AWS_LAMBDA_FUNCTION
  }
}
